<?php

/**
 * @param string $ref
 *
 * @return array
 */
function tolvignetten_get_affiliate_info($ref)
{
	try{
		$request = \wp_remote_get(
			\sprintf(
				"%s%s?%s",
				TOLVIGNETTEN_STORE_DEFAULT_URL,
				'/affiliate/info',
				\http_build_query([
					'ref' => \trim(
						$ref,
						'/ '
					)
				])
			)
		);

		$responseCode = ((int) \wp_remote_retrieve_response_code($request));
		if( 200 !== $responseCode ){
			throw new \Exception(
				'',
				$responseCode
			);
		}
	}
	catch(\Exception $e){
		return array();
	}

	$response = \json_decode(
		(string) \wp_remote_retrieve_body($request),
		true
	);

	return ((!empty($response) && !empty($response['id'])) ? $response : array());
}

/**
 * @param array $affiliate
 *
 * @return boolean
 */
function tolvignetten_store_affiliate($affiliate)
{
	$durationDays = (int) TOLVIGNETTEN_AFFILIATE_COOKIE_DURATION_DAYS;
	if($durationDays <= 0){
		$durationDays = 1;
	}

	return \setcookie(
		TOLVIGNETTEN_AFFILIATE_COOKIE_NAME,
		\json_encode($affiliate),
		(\time() + ((60 * 60 * 24) * $durationDays)),
		TOLVIGNETTEN_AFFILIATE_COOKIE_PATH
	);
}

/**
 * @return array
 */
function tolvignetten_get_stored_affiliate()
{
	$value = !empty($_COOKIE[TOLVIGNETTEN_AFFILIATE_COOKIE_NAME]) ? $_COOKIE[TOLVIGNETTEN_AFFILIATE_COOKIE_NAME] : null;
	if( null === $value ){
		return array();
	}

	$affiliate = \json_decode(
		\stripslashes(
			$value
		),
		true
	);

	return null !== $affiliate ? $affiliate : array();
}

/**
 * @return boolean
 */
function tolvignetten_affiliate_current_page_exists()
{
	$uriPath = \current(
		\explode(
			'?',
			$_SERVER['REQUEST_URI']
		)
	);

	if (empty($uriPath) || $uriPath === '/') {
		return true;
	}

	return !empty(
		\get_page_by_path(
			$uriPath
		)
	);
}

/**
 * @return string|null
 */
function tolvignetten_affiliate_get_custom_affiliate_css()
{
	$affiliate = tolvignetten_get_stored_affiliate();
	if( empty($affiliate) ){
		return null;
	}

	$css = array();

	if( !empty($affiliate['primary_color']) ){
		$css[] = tolvignetten_load_css_template(
			'includes/affiliates/css-templates/custom-affiliate-style.php',
			[
				'textSelector' => TOLVIGNETTEN_AFFILIATE_CSS_SELECTOR_PRIMARY_COLOR_TEXT,
				'bgSelector' => TOLVIGNETTEN_AFFILIATE_CSS_SELECTOR_PRIMARY_COLOR_BG,
				'color' => $affiliate['primary_color']
			]
		);
	}

	if( !empty($affiliate['secondary_color']) ){
		$css[] = tolvignetten_load_css_template(
			'includes/affiliates/css-templates/custom-affiliate-style.php',
			[
				'textSelector' => TOLVIGNETTEN_AFFILIATE_CSS_SELECTOR_SECONDARY_COLOR_TEXT,
				'bgSelector' => TOLVIGNETTEN_AFFILIATE_CSS_SELECTOR_SECONDARY_COLOR_BG,
				'color' => $affiliate['secondary_color']
			]
		);
	}

	return !empty($css) ? \implode("\n", $css) : null;
}

/**
 * @return int|null
 */
function tolvignetten_affiliate_id()
{
	$affiliate = tolvignetten_get_stored_affiliate();
	if( empty($affiliate) ){
		return null;
	}

	return !empty($affiliate['id']) ? ((int) $affiliate['id']) : null;
}

/**
 * @return string|null
 */
function tolvignetten_affiliate_info()
{
	$affiliate = tolvignetten_get_stored_affiliate();
	if( empty($affiliate) ){
		return null;
	}

	return !empty($affiliate['_info']) ? $affiliate['_info'] : null;
}

/**
 * @return string|null
 */
function tolvignetten_affiliate_anvr()
{
	$affiliate = tolvignetten_get_stored_affiliate();
	if( empty($affiliate) ){
		return null;
	}

	return !empty($affiliate['_anvr']) ? $affiliate['_anvr'] : null;
}

/**
 * @return string|null
 */
function tolvignetten_affiliate_bdr()
{
	$affiliate = tolvignetten_get_stored_affiliate();
	if( empty($affiliate) ){
		return null;
	}

	return !empty($affiliate['_bdr']) ? $affiliate['_bdr'] : null;
}