<?php

// Logo manager
require_once \sprintf(
	'%sincludes/logo-manager.php',
	TOLVIGNETTEN_PATH
);

// Affiliates
require_once \sprintf(
	'%sincludes/affiliates/affiliates.php',
	TOLVIGNETTEN_PATH
);

/**
 * @param string $path
 *
 * @return string
 */
function tolvignetten_plugin_url($path)
{
	return \plugins_url(
		$path,
		\realpath(
			__DIR__
		)
	);
}

/**
 * @return string
 */
function tolvignetten_get_default_map_target_url()
{
	return \sprintf(
		'%s%s',
		\get_site_url(),
		'/aanvragen'
	);
}

/**
 * @return string
 */
function tolvignetten_get_default_store_url()
{
	return TOLVIGNETTEN_STORE_DEFAULT_URL;
}

/**
 * @return int
 */
function tolvignetten_get_current_cart_items()
{
	$cookieName = TOLVIGNETTEN_UI_SID_COOKIE_NAME;
	$sid = (!empty($_COOKIE[$cookieName]) ? $_COOKIE[$cookieName] : null);
	if (null === $sid) {
		return 0;
	}

	try {
		$response = \json_decode(
			\wp_remote_get(
				\sprintf(
					'%s/_ajax/order/get-cart-summary?SID=%s',
					\rtrim(
						TOLVIGNETTEN_STORE_DEFAULT_URL,
						'/'
					),
					$sid
				)
			)['body'],
			true
		);
	} catch (\Exception $e) {
		return 0;
	}

	return (int) $response['items'];
}

/**
 * @return string|null
 */
function tolvignetten_get_current_query()
{
	$cookieName = TOLVIGNETTEN_UI_QUERY_COOKIE_NAME;

	return !empty($_COOKIE[$cookieName]) ? \ltrim($_COOKIE[$cookieName], '?') : null;
}

function tolvignetten_enqueue_required_libs()
{
	\wp_enqueue_script(
		'tolvignetten-required-libs',
		tolvignetten_plugin_url('public/js/required-libs.js'),
		['jquery']
	);

	\wp_localize_script('tolvignetten-required-libs', 'TolvignettenPlugin', [
		'pluginUrl' => tolvignetten_plugin_url(''),
	]);
}

/**
 * @param string $path
 * @param array  $vars
 *
 * @return string
 */
function tolvignetten_load_template($path, $vars = [])
{
	if (\is_array($vars)) {
		foreach ($vars as $k => $v) {
			$$k = $v;
		}
	}

	\ob_start();

	include \sprintf(
		'%s%s',
		TOLVIGNETTEN_PATH,
		$path
	);

	return \ob_get_clean();
}

/**
 * @param string $path
 * @param array  $vars
 *
 * @return string
 */
function tolvignetten_load_css_template($path, $vars = [])
{
	return tolvignetten_load_template(
		$path,
		$vars
	);
}

/**
 * @return array
 */
function tolvignetten_get_shortcodes_descriptions()
{
	return [
		TOLVIGNETTEN_MAP_SHORCODE => [
			'name' => 'Map',
			'parameters' => [
				'target_path' => [
					'type' => 'string',
					'description' => 'Target URL for "continue" button.',
					'default_value' => '/aanvragen',
				],
				'reset' => [
					'type' => 'boolean',
					'description' => 'Resets current store session on "continue".',
					'default_value' => 'true',
					'value_map' => function ($value) {
						return tolvignetten_process_input_boolean(
							$value
						);
					},
				],
			],
		],
		TOLVIGNETTEN_STORE_SHORCODE => [
			'name' => 'Store',
			'parameters' => [
				'store_url' => [
					'type' => 'string',
					'description' => 'URL of UI for iframe.',
					'default_value' => tolvignetten_get_default_store_url(),
				],
				'countries' => [
					'type' => 'string',
					'description' => 'ISO code of countries separated by commas.',
					'default_value' => [
						'NL',
					],
					'value_map' => function ($value) {
						if (\is_string($value)) {
							return \explode(
								',',
								\preg_replace(
									"/\s+/",
									'',
									$value
								)
							);
						}

						return $value;
					},
				],
				'partner_id' => [
					'type' => 'string',
					'description' => '',
					'default_value' => '',
				],
				'partner_info' => [
					'type' => 'string',
					'description' => '',
					'default_value' => '',
				],
				'show_trailer_option' => [
					'type' => 'boolean',
					'description' => 'Display "trailer option" checkbox.',
					'default_value' => 'false',
					'value_map' => function ($value) {
						return tolvignetten_process_input_boolean(
							$value
						);
					},
				],
				'allow_delete_main_items' => [
					'type' => 'boolean',
					'description' => '',
					'default_value' => 'false',
					'value_map' => function ($value) {
						return tolvignetten_process_input_boolean(
							$value
						);
					},
				],
				'show_configuration_summary' => [
					'type' => 'boolean',
					'description' => '',
					'default_value' => 'false',
					'value_map' => function ($value) {
						return tolvignetten_process_input_boolean(
							$value
						);
					},
				],
				'show_info' => [
					'type' => 'boolean',
					'description' => '',
					'default_value' => 'false',
					'value_map' => function ($value) {
						return tolvignetten_process_input_boolean(
							$value
						);
					},
				],
			],
		],
		TOLVIGNETTEN_STORE_CART_BUTTON_SHORCODE => [
			'name' => 'Store cart button',
			'parameters' => [
				'target_path' => [
					'type' => 'string',
					'description' => 'Target path.',
					'default_value' => '/aanvragen',
				],
				'style' => [
					'type' => 'string',
					'description' => 'HTML style attribute value.',
					'default_value' => '',
				],
				'icon_style' => [
					'type' => 'string',
					'description' => 'HTML style attribute value for cart icon.',
					'default_value' => '',
				],
			],
		],
	];
}

/**
 * @param mixed $value
 *
 * @return string
 */
function tolvignetten_process_input_boolean($value)
{
	return 'true' === \strtolower($value) ? 'true' : 'false';
}

/**
 * @param array $attrs
 * @param mixed $shortcode
 *
 * @return array
 */
function tolvignetten_process_shotcode_attrs($shortcode, $attrs)
{
	static $shortcodes = null;
	if (null === $shortcodes) {
		$shortcodes = tolvignetten_get_shortcodes_descriptions();
	}

	$return = [];
	if (isset($shortcodes[$shortcode])) {
		foreach ($shortcodes as $k => $v) {
			if (\is_array($shortcodes[$shortcode]['parameters'])) {
				foreach ($shortcodes[$shortcode]['parameters'] as $parameterName => $parameter) {
					$return[$parameterName] = '';
					if (isset($attrs[$parameterName])) {
						$return[$parameterName] = $attrs[$parameterName];
					} elseif (isset($parameter['default_value'])) {
						$return[$parameterName] = $parameter['default_value'];
					}

					if (
						isset($parameter['value_map'])
						&&
						\is_callable($parameter['value_map'])
					) {
						$return[$parameterName] = $parameter['value_map'](
							$return[$parameterName]
						);
					}
				}
			}
		}
	}

	return $return;
}

/**
 * @param string $source
 * @param string $target
 *
 * @return boolean
 */
function tolvignetten_copy($source, $target)
{
	$dir = \opendir($source);
	if (!\is_dir($target)) {
		@\mkdir($target);
	}

	while (false !== ($file = \readdir($dir))) {
		if (preg_match("/^(\.\.?)/", $file)) {
			continue;
		}

		if (\is_dir($source . '/' . $file)) {
			tolvignetten_copy(
				\sprintf(
					"%s/%s",
					$source,
					$file
				),
				\sprintf(
					"%s/%s",
					$target,
					$file
				)
			);

			continue;
		}

		\copy(
			\sprintf(
				"%s/%s",
				$source,
				$file
			),
			\sprintf(
				"%s/%s",
				$target,
				$file
			)
		);
	}

	\closedir($dir);

	return true;
}

/**
 * @param string $directory
 */
function tolvignetten_rmdir($directory)
{
	if (\is_dir($directory)) {
		return;
	}

	$objects = \scandir($directory);
	foreach ($objects as $object) {
		if ($object == "." && $object == "..") {
			continue;
		}

		$objectDir = \sprintf(
			"%s/%s" .
			$directory,
			$object
		);

		if (\is_dir($objectDir)) {
			tolvignetten_rmdir(
				$objectDir
			);
		}
		else {
			\unlink(
				$objectDir
			);
		}
	}

	\reset($objects);
	\rmdir($directory);
}

/**
 * @return array
 */
function tolvignetten_get_templates_child_file_list()
{
	$templatesChildPattern = \sprintf(
		"%stemplates-child/*",
		TOLVIGNETTEN_PATH
	);

	$list = \glob(
		$templatesChildPattern,
		GLOB_ONLYDIR
	);

	return false !== $list ? $list : array();
}

/**
 * @return string
 */
function tolvignetten_get_root_themes_path()
{
	return \realpath(
		\sprintf(
			"%s../../themes/",
			TOLVIGNETTEN_PATH
		)
	);
}